@@ -179,6 +179,8 @@ namespace Mono.WebServer.XSP
 			Console.WriteLine ("    --nonstop: don't stop the server by pressing enter. Must be used");
 			Console.WriteLine ("               when the server has no controlling terminal.");
 			Console.WriteLine ();
+			Console.WriteLine ("    --no-hidden: allow access to hidden files (see 'man xsp' for details)");
+			Console.WriteLine ();
 			Console.WriteLine ("    --version: displays version information and exits.");
 			Console.WriteLine ("    --verbose: prints extra messages. Mainly useful for debugging.");
 			Console.WriteLine ("    --pidfile file: write the process PID to the specified file.");
@@ -260,7 +262,7 @@ namespace Mono.WebServer.XSP
 			while (true) {
 				try {
 					return new Server ().RealMain (args, true, null, quiet);
-				} catch (ThreadAbortException) {
+				} catch (ThreadAbortException ex) {
 					// Single-app mode and ASP.NET appdomain unloaded
 					Thread.ResetAbort ();
 					quiet = true; // hush 'RealMain'
@@ -366,9 +368,11 @@ namespace Mono.WebServer.XSP
 					}
 					break;
 				}
+				case "--no-hidden":
+					MonoWorkerRequest.CheckFileAccess = false;
+					break;
 					
 				default:
-					Console.WriteLine ("Unknown argument: {0}", a);
 					ShowHelp ();
 					return 1;
 				}
@@ -464,15 +468,22 @@ namespace Mono.WebServer.XSP
 					if (!quiet)
 						Console.WriteLine ("Hit Return to stop the server.");
 
+					bool doSleep;
 					while (true) {
+						doSleep = false;
 						try {
 							Console.ReadLine ();
 							break;
 						} catch (IOException) {
 							// This might happen on appdomain unload
 							// until the previous threads are terminated.
-							Thread.Sleep (500);
+							doSleep = true;
+						} catch (ThreadAbortException) {
+							doSleep = true;
 						}
+
+						if (doSleep)
+							Thread.Sleep (500);
 					}
 					server.Stop ();
 				}
